==> apache-cxf-3.6.6-src.zip: apache-cxf-3.6.6-src/rt/frontend/jaxrs/src/main/java/org/apache/cxf/jaxrs/ext/ProtocolHeadersImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jaxrs.ext;

import java.util.List;

import javax.ws.rs.core.MultivaluedMap;

import org.apache.cxf.jaxrs.impl.HttpHeadersImpl;
import org.apache.cxf.message.Message;

public class ProtocolHeadersImpl implements ProtocolHeaders {

    // TODO : introduce a common abstract class instead with
    // ProtocolHeaderImpl and HttpHeadersImpl inheriting from it given that
    // HttpHeadersImpl is just a wrapper around Message.PROTOCOL_HEADERS
    private HttpHeadersImpl httpHeaders;

    public ProtocolHeadersImpl(Message m) {
        httpHeaders = new HttpHeadersImpl(m);
    }

    public List<String> getRequestHeader(String name) {
        return httpHeaders.getRequestHeader(name);
    }

    public String getRequestHeaderValue(String name) {
        List<String> values = getRequestHeader(name);
        return !values.isEmpty() ? values.get(0) : null;
    }

    public MultivaluedMap<String, String> getRequestHeaders() {
        return httpHeaders.getRequestHeaders();
    }

}

==> apache-cxf-4.2.0-src.zip: apache-cxf-4.2.0-src/rt/frontend/jaxrs/src/main/java/org/apache/cxf/jaxrs/ext/ProtocolHeadersImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jaxrs.ext;

import java.util.List;

import jakarta.ws.rs.core.MultivaluedMap;
import org.apache.cxf.jaxrs.impl.HttpHeadersImpl;
import org.apache.cxf.message.Message;

public class ProtocolHeadersImpl implements ProtocolHeaders {

    // TODO : introduce a common abstract class instead with
    // ProtocolHeaderImpl and HttpHeadersImpl inheriting from it given that
    // HttpHeadersImpl is just a wrapper around Message.PROTOCOL_HEADERS
    private HttpHeadersImpl httpHeaders;

    public ProtocolHeadersImpl(Message m) {
        httpHeaders = new HttpHeadersImpl(m);
    }

    public List<String> getRequestHeader(String name) {
        return httpHeaders.getRequestHeader(name);
    }

    public String getRequestHeaderValue(String name) {
        List<String> values = getRequestHeader(name);
        return !values.isEmpty() ? values.get(0) : null;
    }

    public MultivaluedMap<String, String> getRequestHeaders() {
        return httpHeaders.getRequestHeaders();
    }

}
